@@ -31,11 +31,11 @@ static const struct shishi_error_msgs _shishi_error_messages[] = {
   {SHISHI_OK,
    N_("Shishi success")},
   {SHISHI_ASN1_ERROR,
-   N_("Error in ASN.1 data, probably due to corrupt data.")},
+   N_("Error in ASN.1 function (corrupt data?)")},
   {SHISHI_FOPEN_ERROR,
-   N_("Could not open file.")},
+   N_("Could not open file")},
   {SHISHI_IO_ERROR,
-   N_("File input/output error.")},
+   N_("File input/output error")},
   {SHISHI_MALLOC_ERROR,
    N_("Memory allocation error in shishi library.")},
   {SHISHI_BASE64_ERROR,
@@ -80,6 +80,8 @@ static const struct shishi_error_msgs _shishi_error_messages[] = {
   {SHISHI_TICKET_DECRYPT_FAILED,
    N_("Could not decrypt Ticket using provided key. "
       "This usually indicates an internal application error.")},
+  {SHISHI_KEYTAB_ERROR,
+   N_("Failed to parse keytab file")},
   {-1, NULL}
 };
 
@@ -302,3 +304,41 @@ shishi_warn (Shishi * handle, const char *format, ...)
   free (out);
   va_end (ap);
 }
+
+/**
+ * shishi_verbose:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @format: printf style format string.
+ * @...: print style arguments.
+ *
+ * Print a diagnostic message to output as defined in handle.
+ **/
+void
+shishi_verbose (Shishi * handle, const char *format, ...)
+{
+  va_list ap;
+  char *out;
+  int type;
+
+  if (!VERBOSE (handle))
+    return;
+
+  va_start (ap, format);
+  vasprintf (&out, format, ap);
+
+  type = shishi_error_outputtype (handle);
+  switch (type)
+    {
+    case SHISHI_OUTPUTTYPE_STDERR:
+      fprintf (stderr, "%s\n", out);
+      break;
+    case SHISHI_OUTPUTTYPE_SYSLOG:
+      syslog (LOG_DEBUG, "%s", out);
+      break;
+    default:
+      break;
+    }
+
+  free (out);
+  va_end (ap);
+}
