@@ -26,37 +26,23 @@
 #include "config.h"
 #endif
 
-#ifdef STDC_HEADERS
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <ctype.h>
 #include <string.h>
-#endif
-
 #include <stdbool.h>
 #include <stdint.h>
-
-#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#endif
-
 #include <sys/socket.h>
-
-#ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
-#endif
+#include <sys/stat.h>
+#include <unistd.h>
 
 #ifdef HAVE_SYS_IOCTL_H
 #include <sys/ioctl.h>
 #endif
 
-#ifdef HAVE_SYS_STAT_H
-#include <sys/stat.h>
-#endif
-
-#include <unistd.h>
-
 #ifdef HAVE_NETDB_H
 #include <netdb.h>
 #endif
@@ -120,6 +106,7 @@
 #include "base64.h"
 #include "getdate.h"
 #include "getline.h"
+#include "read-file.h"
 #include "strtok_r.h"
 #include "time_r.h"
 #include "timegm.h"
