@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.26"
+#define SHISHI_VERSION "0.0.27"
 
 /* Error codes */
 typedef enum
@@ -84,7 +84,8 @@ typedef enum
   SHISHI_FILE_ERROR = 49,
   SHISHI_ENCAPREPPART_BAD_KEYTYPE = 50,
   SHISHI_GETTIMEOFDAY_ERROR = 51,
-  SHISHI_LAST_ERROR = 51
+  SHISHI_KEYTAB_ERROR = 52,
+  SHISHI_LAST_ERROR = 52
 }
 Shishi_rc;
 
@@ -601,6 +602,7 @@ typedef struct Shishi_as Shishi_as;
 typedef struct Shishi_tgs Shishi_tgs;
 typedef struct Shishi_ap Shishi_ap;
 typedef struct Shishi_key Shishi_key;
+typedef struct Shishi_keys Shishi_keys;
 typedef struct Shishi_safe Shishi_safe;
 typedef struct Shishi_priv Shishi_priv;
 #ifndef _SHISHI_HAS_LIBTASN1_H
@@ -652,6 +654,7 @@ extern int shishi_error_outputtype (Shishi * handle);
 extern void shishi_error_set_outputtype (Shishi * handle, int type);
 extern void shishi_info (Shishi * handle, const char *format, ...);
 extern void shishi_warn (Shishi * handle, const char *format, ...);
+extern void shishi_verbose (Shishi * handle, const char *format, ...);
 
 /* realm.c */
 extern char *shishi_realm_default_guess (void);
@@ -1817,7 +1820,8 @@ extern void shishi_key_version_set (Shishi_key * key, uint32_t kvno);
 extern int shishi_key (Shishi * handle, Shishi_key ** key);
 extern void shishi_key_done (Shishi_key * key);
 extern void shishi_key_copy (Shishi_key * dstkey, Shishi_key * srckey);
-extern int shishi_key_print (Shishi * handle, FILE * fh, Shishi_key * key);
+extern int shishi_key_print (Shishi * handle, FILE * fh,
+			     const Shishi_key * key);
 extern int shishi_key_to_file (Shishi * handle,
 			       const char *filename, Shishi_key * key);
 extern int shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key);
@@ -1847,6 +1851,31 @@ extern int shishi_key_from_name (Shishi * handle,
 				 Shishi_key ** outkey);
 
 /* keys.c */
+extern int shishi_keys (Shishi * handle, Shishi_keys ** keys);
+extern void shishi_keys_done (Shishi_keys ** keys);
+extern int shishi_keys_size (Shishi_keys * keys);
+extern const Shishi_key *shishi_keys_nth (Shishi_keys * keys, int keyno);
+extern void shishi_keys_remove (Shishi_keys * keys, int keyno);
+extern int shishi_keys_add (Shishi_keys * keys, Shishi_key * key);
+
+extern int shishi_keys_add_keytab_mem (Shishi * handle,
+				       const char *data, size_t len,
+				       Shishi_keys *keys);
+extern int shishi_keys_add_keytab_file (Shishi * handle,
+					const char *filename,
+					Shishi_keys *keys);
+extern int shishi_keys_from_keytab_mem (Shishi * handle,
+					const char *data, size_t len,
+					Shishi_keys **outkeys);
+extern int shishi_keys_from_keytab_file (Shishi * handle,
+					 const char *filename,
+					 Shishi_keys **outkeys);
+
+extern int shishi_keys_print (Shishi_keys * keys, FILE *fh);
+extern int shishi_keys_to_file (Shishi * handle,
+				const char *filename,
+				Shishi_keys * keys);
+
 extern Shishi_key *shishi_keys_for_serverrealm_in_file (Shishi * handle,
 							const char *filename,
 							const char *server,
